@@ -77,14 +77,14 @@ typedef enum {
     MOMENT_COMPONENT_MINUTE,
     MOMENT_COMPONENT_SECOND,
     MOMENT_COMPONENT_NANOSECOND,
-    MOMENT_COMPONENT_OFFSET,
 } moment_component_t;
 
 moment_t    THX_moment_new(pTHX_ IV Y, IV M, IV D, IV h, IV m, IV s, IV ns, IV offset);
 moment_t    THX_moment_from_epoch(pTHX_ int64_t sec, IV usec, IV offset);
 
 moment_t    THX_moment_with_component(pTHX_ const moment_t *mt, moment_component_t u, IV v);
-moment_t    THX_moment_with_offset(pTHX_ const moment_t *mt, IV offset);
+moment_t    THX_moment_with_offset_same_instant(pTHX_ const moment_t *mt, IV offset);
+moment_t    THX_moment_with_offset_same_local(pTHX_ const moment_t *mt, IV offset);
 moment_t    THX_moment_with_nanosecond(pTHX_ const moment_t *mt, IV nsec);
 
 moment_t    THX_moment_plus_unit(pTHX_ const moment_t *mt, moment_unit_t u, int64_t v);
@@ -124,8 +124,11 @@ int64_t     moment_epoch(const moment_t *mt);
 #define moment_from_epoch(sec, nsec, offset) \
     THX_moment_from_epoch(aTHX_ sec, nsec, offset)
 
-#define moment_with_offset(self, offset) \
-    THX_moment_with_offset(aTHX_ self, offset)
+#define moment_with_offset_same_instant(self, offset) \
+    THX_moment_with_offset_same_instant(aTHX_ self, offset)
+
+#define moment_with_offset_same_local(self, offset) \
+    THX_moment_with_offset_same_local(aTHX_ self, offset)
 
 #define moment_with_nanosecond(self, nsec) \
     THX_moment_with_nanosecond(aTHX_ self, nsec)
